==> campsite-2.4.1.tbz: campsite/www-common/html/priv/lang/sr/pub.php <==
<?php
regGS("Publication List", "Листа публикација");
regGS("Go To Issues", "Иди на издања");
regGS("Name<BR><SMALL>(click to see issues)</SMALL>", "Име<br><small>(кликните за преглед издања)</small>");
regGS("Delete publication $1", "Обриши публикацију $1");
regGS("No publications.", "Нема публикација");
regGS("Default Site Alias", "Основни сајт алиас");
regGS("URL Type", "тип УРЛа");
regGS("Country<BR><SMALL>(click to edit)</SMALL>", "Држава<br><small>(кликните за уређивање)</small>");
regGS("Delete alias $1", "Обриши податак $1");
regGS("Configure publication", "Подеси публикацију");
regGS("You do not have the right to edit publication information.", "Немате право да уређујете податке о публикацији");
regGS("General attributes", "Општи атрибути");
regGS("Subscriptions defaults", "Основни подаци о претплатама");
regGS("Countries defaults", "Основни подаци о државама");
regGS("Changing publication information", "Мењање података о публикацији");
regGS("You do not have the right to change publication information.", "Немате право измене података о публикацији");
regGS("The publication information could not be updated.", "Подаци о публикацији не могу бити измењени");
regGS("Please check if another publication with the same name or the same site name does not already exist.", "Проверите да ли већ постоји публикација са истим именом или именом сајта ");
regGS("You do not have the right to delete publications.", "Немате право да бришете публикације");
regGS("Are you sure you want to delete the publication $1?", "Сигурни сте да желите да обришете публикацију $1?");
regGS("Deleting publication", "Брисање публикације");
regGS("There are $1 subscription(s) left.", "Преостало је $1 претплата");
regGS("The publication $1 could not be deleted.", "Публикација $1 не може бити обрисана");
regGS("Adding new publication", "Додавање нове публикације");
regGS("The publication could not be added.", "Публикација не може бити додата");
regGS("Select the publication", "Изаберите публикацију");
regGS("Add new country default subscription time", "Додај нови основни период претплате за државу");
regGS("You do not have the right to manage publications.", "Немате право да администрирате публикацијама");
regGS("Please check if another entry with the same country code exists already.", "Проверите да ли већ постоји унос са истим кодом државе");
regGS("Adding new country default subscription time", "Додавање новог основног периода претплате за државу");
regGS("You must select a country.", "Морате изабрати државу");
regGS("The default subscription time for country $1 could not be added.", "Нови период претплате за $1 не може бити додат");
regGS("Change subscription default time", "Промени трајање основне претплате");
regGS("Default subscription time for $1 changed", "Трајање основне претплате за $1 промењено");
regGS("Are you sure you want to delete the subscription default time for $1?", "Сигурни сте да желите да обришете основну дужину претплате за $1?");
regGS("Subscription default time for $1 deleted", "Дужина претплате за $1 је избрисана");
regGS("Name<BR><SMALL>(click to select the publication)</SMALL>", "Назив<br><small>(кликните за избор публикације)</small>");
regGS("Add new alias", "Додај нови алиас");
regGS("Alias (click to edit)", "Алиас (клик за уређивање)");
regGS("Edit aliases", "Уреди алиасе");
regGS("Publication Aliases", "алиаси за публикацију");
regGS("Adding new alias", "додавање новог алиаса");
regGS("The site alias $1 has been added to publication $2.", "Сајт алиас $1 је додат у публикацију $2.");
regGS("The site alias $1 could not be added.", "сајт алиас $1 не може бити додат.");
regGS("Another alias with the same name exists already.", "Већ постоји алиас са истим именом");
regGS("Edit alias", "Уреди алиас");
regGS("Editing alias", "Уређивање алиаса");
regGS("The site alias for publication $1 has been modified to $2.", "Сајт алиас за публикацију $1 је промењен у $2.");
regGS("The site alias $1 could not be modified.", "Сајт алиас $1 не може бити промењен.");
regGS("Are you sure you want to delete the alias $1?", "Да ли сте сигурни да желите да обришете алиас $1?");
regGS("Deleting alias", "Брисање алиаса");
regGS("The alias $1 could not be deleted.", "алиас $1 не може бити обрисан.");
regGS("The alias $1 has been deleted from publication $2.", "Алиас $1 је обрисан из публикације $2.");
regGS("$1 is the default publication alias, it can not be deleted.", "$1 је основни алиас за публикацију, па не може бити обрисан.");
regGS("You do not have the right to add publications.", "Немате право да додајете публикације.");
regGS("There are $1 issue(s) left.", "Преостало је $1 издања.");
regGS("The default subscription time for $1 has been added.", "Нови период претплате за $1 додат");
?>

==> campsite-2.6.1.tbz: campsite/www-common/html/priv/lang/sr/pub.php <==
<?php 
regGS("Use CAPTCHA to prevent spam?", "");
regGS("Public allowed to comment?", "");
regGS("Enable spam blocking?", "");
regGS("The subscription settings for '$1' could not be added.", "");
regGS("The publication name you specified conflicts with publication '$1'.", "");
regGS("The publication alias you specified conflicts with publication '$1'.", "");
regGS("Subscription defaults", "");
regGS("Subscription Settings by Country", "");
regGS("Set subscription settings for a country", "");
regGS("Set subscription settings by country", "");
regGS("Default time periods:", "");
regGS("Country subscription settings updated.", "");
regGS("Country subscription settings deleted.", "");
regGS("Change country subscription settings", "");
regGS("Are you sure you want to delete the subscription settings for $1?", "");
regGS("Publication updated", "");
regGS("Subscriber comments moderated?", "");
regGS("Public comments moderated?", "");
regGS("Comments enabled?", "");
regGS("Comments enabled", "");
regGS("Article comments default to enabled?", "");
regGS("trial subscription", "пробна претплата");
regGS("paid subscription", "плаћена претплата");
regGS("time units", "временске јединице");
regGS("one language", "један језик");
regGS("all languages", "сви језици");
regGS("Trial subscriptions", "Пробне претплате");
regGS("Time unit cost per one section", "Цена по временској јединици за рубрику");
regGS("Paid subscriptions", "Плаћене претплате");
regGS("Default time period", "Подразумевани временски период");
regGS("Go To Issues", "Иди на издања");
regGS("Name<BR><SMALL>(click to see issues)</SMALL>", "Име<br><small>(кликните за преглед издања)</small>");
regGS("Delete publication $1", "Обриши публикацију $1");
regGS("No publications.", "Нема публикација");
regGS("Default Site Alias", "Основни сајт алиас");
regGS("URL Type", "тип УРЛа");
regGS("Country<BR><SMALL>(click to edit)</SMALL>", "Држава<br><small>(кликните за уређивање)</small>");
regGS("Delete alias $1", "Обриши податак $1");
regGS("Configure publication", "Подеси публикацију");
regGS("You do not have the right to edit publication information.", "Немате право да уређујете податке о публикацији");
regGS("General attributes", "Општи атрибути");
regGS("You do not have the right to change publication information.", "Немате право измене података о публикацији");
regGS("The publication information could not be updated.", "Подаци о публикацији не могу бити измењени");
regGS("You do not have the right to delete publications.", "Немате право да бришете публикације");
regGS("Are you sure you want to delete the publication $1?", "Сигурни сте да желите да обришете публикацију $1?");
regGS("Deleting publication", "Брисање публикације");
regGS("There are $1 subscription(s) left.", "Преостало је $1 претплата");
regGS("The publication $1 could not be deleted.", "Публикација $1 не може бити обрисана");
regGS("The publication could not be added.", "Публикација не може бити додата");
regGS("You do not have the right to manage publications.", "Немате право да администрирате публикацијама");
regGS("You must select a country.", "Морате изабрати државу");
regGS("Default subscription time for $1 changed", "Трајање основне претплате за $1 промењено");
regGS("Subscription default time for $1 deleted", "Дужина претплате за $1 је избрисана");
regGS("Add new alias", "Додај нови алиас");
regGS("Alias (click to edit)", "Алиас (клик за уређивање)");
regGS("Edit aliases", "Уреди алиасе");
regGS("Publication Aliases", "алиаси за публикацију");
regGS("Adding new alias", "Додавање новог алиаса");
regGS("The site alias $1 has been added to publication $2.", "Сајт алиас $1 је додат у публикацију $2.");
regGS("The site alias $1 could not be added.", "Сајт алиас $1 не може бити додат.");
regGS("Another alias with the same name exists already.", "Већ постоји алиас са истим именом");
regGS("Edit alias", "Уреди алиас");
regGS("Editing alias", "Уређивање алиаса");
regGS("The site alias for publication $1 has been modified to $2.", "Сајт алиас за публикацију $1 је промењен у $2.");
regGS("The site alias $1 could not be modified.", "Сајт алиас $1 не може бити промењен.");
regGS("Are you sure you want to delete the alias $1?", "Да ли сте сигурни да желите да обришете алиас $1?");
regGS("Deleting alias", "Брисање алиаса");
regGS("The alias $1 could not be deleted.", "Алиас $1 не може бити обрисан.");
regGS("The alias $1 has been deleted from publication $2.", "Алиас $1 је обрисан из публикације $2.");
regGS("$1 is the default publication alias, it can not be deleted.", "$1 је основни алиас за публикацију, па не може бити обрисан.");
regGS("You do not have the right to add publications.", "Немате право да додајете публикације.");
regGS("There are $1 issue(s) left.", "Преостало је $1 издања.");
regGS("The default subscription time for $1 has been added.", "Нови период претплате за $1 додат");
regGS("Time Unit", "Временска јединица");
regGS("Currency", "Валута");
regGS("Edit languages", "Прикажи језике");
?>
